@@ -95,13 +95,14 @@ class RPSDockerArena():
             print(f"Health check failed for {url}: {e}")
             return None
     
-    def build_and_run_container(self, bot_id, port):
+    def build_and_run_container(bot_id, port):
+        client = docker.from_env()
         image_name = f"rps_bot_{bot_id}"
         container_name = f"rps_container_{bot_id}"
 
         # Build the container
         try:
-            self.client.images.build(
+            client.images.build(
                 path=f"./submissions/rps_submissions/{bot_id}/",
                 dockerfile="Dockerfile",
                 tag=image_name
@@ -113,7 +114,7 @@ class RPSDockerArena():
 
         # Run the container
         try:
-            container = self.client.containers.run(
+            container = client.containers.run(
                 image_name,
                 name=container_name,
                 detach=True,
